==> fireflow-0.0.74.tar.gz: lib/src/comment/comment.model.dart <==
import 'dart:math';

import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:fireflow/fireflow.dart';

/// CommentModel is a class that represents a document of /comments.
///
class CommentModel {
  final String id;
  final DocumentReference postDocumentReference;
  final DocumentReference? parentCommentDocumentReference;
  final DocumentReference userDocumentReference;
  final String category;
  final String content;
  final String safeContent;
  final String order;
  final int depth;
  final bool deleted;
  final List<String> files;

  final Timestamp createdAt;
  final Timestamp updatedAt;

  final DocumentReference ref;

  CommentModel({
    required this.id,
    required this.postDocumentReference,
    required this.parentCommentDocumentReference,
    required this.userDocumentReference,
    required this.category,
    required this.content,
    required this.safeContent,
    required this.order,
    required this.depth,
    required this.createdAt,
    required this.updatedAt,
    required this.deleted,
    required this.files,
    required this.ref,
  });

  /// Create a CommentModel object from a snapshot of a document.
  factory CommentModel.fromSnapshot(DocumentSnapshot snapshot) {
    return CommentModel.fromJson(
      snapshot.data() as Map<String, dynamic>,
      id: snapshot.id,
    );
  }

  /// Create a CommentModel object from a json object.
  factory CommentModel.fromJson(
    Map<String, dynamic> json, {
    required String id,
  }) {
    return CommentModel(
      id: id,
      postDocumentReference: json['postDocumentReference'],
      parentCommentDocumentReference: json['parentCommentDocumentReference'],
      userDocumentReference: json['userDocumentReference'],
      category: json['category'] ?? '',
      content: json['content'] ?? '',
      safeContent: _safeContent(json['content']),
      order: json['order'] ?? '',
      depth: json['depth'] ?? 0,
      deleted: json['deleted'] ?? false,
      files: json['files'] ?? [],
      createdAt: json['createdAt'] ?? Timestamp.now(),
      updatedAt: json['updatedAt'] ?? Timestamp.now(),
      ref: CommentService.instance.doc(id),
    );
  }

  // create "toString()" method that returns a string of the object of this class
  @override
  String toString() {
    return 'CommentModel{ postDocumentReference: $postDocumentReference, parentCommentDocumentReference: $parentCommentDocumentReference, userDocumentReference: $userDocumentReference, category: $category, content: $content, order: $order, depth: $depth, createdAt: $createdAt, updatedAt: $updatedAt}';
  }

  static String _safeContent(String? content) {
    if (content == null) {
      return '';
    }
    content = content.replaceAll(RegExp(r'<[^>]*>'), '');
    content = content.replaceAll('\r', '');
    content = content.replaceAll('\n', ' ');
    content = content.replaceAll('\t', ' ');
    content = content.substring(0, min(content.length, 64));
    return content;
  }
}

==> fireflow-0.0.75.tar.gz: lib/src/comment/comment.model.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:fireflow/fireflow.dart';

/// CommentModel is a class that represents a document of /comments.
///
class CommentModel {
  final String id;
  final DocumentReference postDocumentReference;
  final DocumentReference? parentCommentDocumentReference;
  final DocumentReference userDocumentReference;
  final String category;
  final String content;
  final String safeContent;
  final String order;
  final int depth;
  final bool deleted;
  final List<String> files;

  final Timestamp createdAt;
  final Timestamp updatedAt;

  final DocumentReference ref;

  CommentModel({
    required this.id,
    required this.postDocumentReference,
    required this.parentCommentDocumentReference,
    required this.userDocumentReference,
    required this.category,
    required this.content,
    required this.safeContent,
    required this.order,
    required this.depth,
    required this.createdAt,
    required this.updatedAt,
    required this.deleted,
    required this.files,
    required this.ref,
  });

  /// Create a CommentModel object from a snapshot of a document.
  factory CommentModel.fromSnapshot(DocumentSnapshot snapshot) {
    return CommentModel.fromJson(
      snapshot.data() as Map<String, dynamic>,
      id: snapshot.id,
    );
  }

  /// Create a CommentModel object from a json object.
  factory CommentModel.fromJson(
    Map<String, dynamic> json, {
    required String id,
  }) {
    return CommentModel(
      id: id,
      postDocumentReference: json['postDocumentReference'],
      parentCommentDocumentReference: json['parentCommentDocumentReference'],
      userDocumentReference: json['userDocumentReference'],
      category: json['category'] ?? '',
      content: json['content'] ?? '',
      safeContent: safeString(json['content']),
      order: json['order'] ?? '',
      depth: json['depth'] ?? 0,
      deleted: json['deleted'] ?? false,
      files: json['files'] ?? [],
      createdAt: json['createdAt'] ?? Timestamp.now(),
      updatedAt: json['updatedAt'] ?? Timestamp.now(),
      ref: CommentService.instance.doc(id),
    );
  }

  // create "toString()" method that returns a string of the object of this class
  @override
  String toString() {
    return 'CommentModel{ postDocumentReference: $postDocumentReference, parentCommentDocumentReference: $parentCommentDocumentReference, userDocumentReference: $userDocumentReference, category: $category, content: $content, order: $order, depth: $depth, createdAt: $createdAt, updatedAt: $updatedAt}';
  }
}
